@@ -15,7 +15,7 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 /**
@@ -604,18 +604,22 @@ anjuta_ui_add_action_group (AnjutaUI *ui,
 		if (icon)
 		{
 			GtkWidget *dummy = gtk_label_new ("Dummy");
+			g_object_ref_sink(G_OBJECT(dummy));
 			pixbuf = gtk_widget_render_icon (dummy, icon,
 											 GTK_ICON_SIZE_MENU, NULL);
-			gtk_tree_store_set (GTK_TREE_STORE (ui->priv->model), &iter,
-								COLUMN_PIXBUF, pixbuf,
-								COLUMN_ACTION, action_label,
-								COLUMN_VISIBLE, gtk_action_get_visible (action),
-								COLUMN_SENSITIVE, gtk_action_get_sensitive(action),
-								COLUMN_DATA, action,
-								COLUMN_GROUP, action_group_name,
-								-1);
-			g_object_unref (G_OBJECT (pixbuf));
-			gtk_widget_destroy (dummy);
+			if (pixbuf)
+			{
+				gtk_tree_store_set (GTK_TREE_STORE (ui->priv->model), &iter,
+									COLUMN_PIXBUF, pixbuf,
+									COLUMN_ACTION, action_label,
+									COLUMN_VISIBLE, gtk_action_get_visible (action),
+									COLUMN_SENSITIVE, gtk_action_get_sensitive(action),
+									COLUMN_DATA, action,
+									COLUMN_GROUP, action_group_name,
+									-1);
+				g_object_unref (G_OBJECT (pixbuf));
+			}
+			g_object_unref (dummy);
 			g_free (icon);
 		}
 		else
@@ -631,6 +635,8 @@ anjuta_ui_add_action_group (AnjutaUI *ui,
 		g_free (action_label);
 	}
 	
+	g_list_free(actions);
+	
 	/* If there are no actions in the group, removed the group node */
 	if (n_actions_added == 0)
 		gtk_tree_store_remove (GTK_TREE_STORE (ui->priv->model),
@@ -669,7 +675,7 @@ anjuta_ui_remove_action_group (AnjutaUI *ui, GtkActionGroup *action_group)
 	valid = gtk_tree_model_get_iter_first (model, &iter);
 	while (valid)
 	{
-		const gchar *group;
+		gchar *group;
 		const gchar *group_name;
 		
 		gtk_tree_model_get (model, &iter, COLUMN_GROUP, &group, -1);
@@ -686,6 +692,7 @@ anjuta_ui_remove_action_group (AnjutaUI *ui, GtkActionGroup *action_group)
 		}
 		else
 			valid = gtk_tree_model_iter_next (model, &iter);
+		g_free(group);
 	}
 	gtk_ui_manager_remove_action_group (GTK_UI_MANAGER (ui), action_group);
 	
